pub fn initialize<A, SDA, SCL>(
mapping: A,
sda: SDA,
scl: SCL,
) -> Initialize<A, SDA, SCL> ⓘExpand description
Creates a new Initialize based off of a I²C bus pin mapping, as well as an SDA and SCL pin.
pub fn initialize<A, SDA, SCL>(
mapping: A,
sda: SDA,
scl: SCL,
) -> Initialize<A, SDA, SCL> ⓘCreates a new Initialize based off of a I²C bus pin mapping, as well as an SDA and SCL pin.